@@ -24,9 +24,9 @@ author = "Egemen Imre"
 # Version Info
 # ------------
 # The short X.Y version.
-version = "0.1"
+version = "0.1.1"
 # The full version, including alpha/beta/rc tags.
-release = "0.1"
+release = "0.1.1"
 
 # -- General configuration ---------------------------------------------------
 # By default, highlight as Python 3.
@@ -62,6 +62,7 @@ master_doc = "index"
 
 # Intersphinx configuration
 intersphinx_mapping = {
+    "pyerfa": ("https://pyerfa.readthedocs.io/en/stable/", None),
     "python": ("https://docs.python.org/3", None),
     "astropy": ("https://docs.astropy.org/en/stable/", None),
     "numpy": ("https://numpy.org/doc/stable/", None),
